#include <stdarg.h>
#include <stdio.h>

#include "debug.h"

/** @file debug.c
 *  @brief the imlementation of <tt>dbg_print()</tt>
 *  @details This function shows you how to write functions like <tt>printf()</tt>
 *  that have a variable number of parameters. You might change the function to
 *  output to a file, instead of <tt>stderr</tt>. This would require a function
 *  to open the <tt>FILE*</tt> (likely a global varaible), at the beginning
 *  of the program and closing it at the end.
 */

bool debug_on = false; // set to non-zero to trun on debugging

void dbg_printf(const char *fmt, ...)
{
  if (debug_on) {
    fprintf(stderr, "DEBUG: ");
    va_list args;
    va_start(args, fmt);
    vfprintf(stderr, fmt, args);
    va_end(args);
    fprintf(stderr, "\n");
  }
}
